using System;
using System.Collections.Generic;
using System.Text;
using ModuloComum;

namespace Telecomunicacoes
{
    public interface ICartao
    {
        /// <summary>
        /// Permite fazer a criao de um novo carto que est associado a um cliente genrico 0 e que assume como data de emisso 
        ///  data corrente
        /// </summary>
        /// <param name="login"></param>
        /// <param name="password"></param>
        /// <param name="numeroTelefoneAssociado"></param>
        /// <param name="codigoTarifarioAssociado"></param>
        /// <returns></returns>
        int CriaCartao(string login, string password, int numeroTelefoneAssociado, int codigoTarifarioAssociado);
        /// <summary>
        /// Permite fazer a criao de um novo carto
        /// </summary>
        /// <param name="login">login do utilizador corrente</param>
        /// <param name="password">password do utilizador corrente</param>
        /// <param name="codigoCliente">cdigo do cliente para quem vai ser criado o carto</param>
        /// <param name="numeroTelefoneAssociado">Nmero de telefone associado</param>
        /// <param name="dataEmissao">Data de emisso do carto</param>
        /// <param name="saldoActual">Saldo Actual</param>
        /// <param name="codigoTarifarioAssociado">Cdigo do Tarifrio associado</param>
        /// <returns>Cdigo do carto criado</returns>
        int CriaCartao(string login, string password, int codigoCliente, int numeroTelefoneAssociado, string dataEmissao, float saldoActual, int codigoTarifarioAssociado);
        
        /// <summary>
        /// Cria um carto e associa um nmero disponivel indicado. Se o nmero indicado no estiver disponvel, ou seja se este nmero estiver associado a um outro carto activo,
        /// a operao no se realiza com sucesso.
        /// </summary>
        /// <param name="login">Login do utilizador autenticado no sistema</param>
        /// <param name="password">Password do utilizador autenticado</param>
        /// <param name="numeroAssociado">Nmero de telefone a associar ao carto.</param>
        /// <returns>true se associao bem efectuada, false se ocorreu uma falha ao executar a associao</returns>
        TelecomunicacoesEnum.EnumGeral CriaCartao(string login, string password, string numeroAssociado);
        /// <summary>
        /// Cria um carto com um nmero associado e associa-o a um cliente. Esta operao poder falhar nas seguintes situaes:
        /// - Se o cliente no existe no sistema
        /// - Se o nmero estiver associado a um carto activo
        /// </summary>
        /// <param name="login">Login do utilizador autenticado no sistema</param>
        /// <param name="password">Password do utilizador autenticado no sistema</param>
        /// <param name="numeroAssociado">Nmero de telefone a associar.</param>
        /// <param name="codigoCliente">Cdigo do cliente.</param>
        /// <returns>true se operao bem sucedida, false se ocorreu um erro na associao.</returns>
        TelecomunicacoesEnum.EnumGeral CriaCartao(string login, string password,string numeroAssociado, int codigoCliente);
        /// <summary>
        /// Mtodo que cria um carto e associa-o a um plano tarifrio.
        /// </summary>
        /// <param name="login">Login para efeitos de autenticao no mtodo.</param>
        /// <param name="password">Password para efeitos de autenticao no mtodo</param>
        /// <param name="codigoPlanoTarifario">Cdigo do plano tarifrio ao qual estamos a associar o carto.</param>
        /// <returns>Enumerrio que indica o sucesso ou insucesso da operao desencadeada pelo mtodo.</returns>
        TelecomunicacoesEnum.EnumGeral CriaCartao(string login, string password, int codigoPlanoTarifario);
        /// <summary>
        /// Mtodo que permite associar um carto a um nmero de telefone. Este mtodo poder devolver false caso o nmero a associar 
        /// esteja neste momento activo com outro carto. Para que a associao seja feita com sucesso deve verificar se o nmero em causa
        /// no est associado a nenhum carto activo.
        /// </summary>
        /// <param name="login">login do utilizador activo no sistema</param>
        /// <param name="password">password do utilizador activo no sistema</param>
        /// <param name="numeroCartao">nmero do carto a associar</param>
        /// <param name="numeroTelefone">Nmero de telefone a associar ao carto</param>
        /// <returns></returns>
        TelecomunicacoesEnum.EnumGeral AssociaNumeroAoCartao(string login, string password, string numeroCartao,string numeroTelefone);
        /// <summary>
        /// 
        /// </summary>
        /// <param name="login"></param>
        /// <param name="password"></param>
        /// <param name="numeroTelefone"></param>
        /// <returns></returns>
        string ObterNumeroDeCartao(string login, string password, string numeroTelefone);
        /// <summary>
        /// Mtodo que altera o plano tarifrio associado a um carto.
        /// Neste mtodo deve ser passado o nmero de telefone ou o nmero do carto do qual se pretende alterar a tarifa de acordo com o seguinte exemplo:
        /// AlteraPlanoTarifario("login1", "xpto1","900101010","",999)
        /// ou
        /// AlteraPlanoTarifario("login1", "xpto1","","AB325679S05",999)
        /// A alterao de um carto para um plano de tarifa do tipo assinatura, implica a validao de determinadas condies, tais como a identificao correcta do cliente associada 
        /// e a inexistencia de passivos anteriores. Caso ocorra alguma destas situaes a alterao no ser realizada com sucesso.
        /// </summary>
        /// <param name="login">Login para efeitos de autenticao</param>
        /// <param name="password">Password para efeitos de autenticao</param>
        /// <param name="numeroTelefone">Nmero de telefone do qual se pretende alterar o plano de tarifrio.</param>
        /// <param name="numeroCartao">Nmero do carto</param>
        /// <param name="codigoTarifa">Cdigo da nova tarifa</param>
        /// <returns>Devolve um identificador que indica se a operao foi concluida ou no com sucesso, indicando em caso de insucesso o motivo do insucesso.</returns>
        TelecomunicacoesEnum.EnumGeral AlteraPlanoTarifario(string login, string password,string numeroTelefone, string numeroCartao,int codigoTarifa);
        /// <summary>
        /// Mtodo que permite cancelar um carto.Este mtodo aceita que seja omitido um dos parametros (numeroCartao,numeroTelefone). Assim sendo o parmetro homitido
        /// dever ser passado de acordo com o seguinte exemplo:
        /// CancelarCartao("login1", "xpto1","AB325679S05","")
        /// ou 
        /// CancelarCartao("login1", "xpto1","","909109101")
        /// </summary>
        /// <param name="login">Login para efeitos de autenticao no mtodo.</param>
        /// <param name="password">Password para efeitos de autenticao no mtodo.</param>
        /// <param name="numeroCartao">Nmero do carto que se pretende cancelar.</param>
        /// <param name="numeroTelefone">Nmero de telefone do carto que se pretende cancelar.</param>
        /// <returns>Enumerrio contendo a indicao do sucesso ou insucesso da operao. </returns>
        TelecomunicacoesEnum.EnumGeral CancelarCartao(string login, string password, string numeroCartao, string numeroTelefone);
        /// <summary>
        /// Mtodo que permite gerar facturas para todos os cartes nmeros de telefone activos.
        /// </summary>
        /// <param name="login">login do utilizador corrente para efeitos de autenticao</param>
        /// <param name="password">password do utilizador corrente para efeitos de autenticao</param>
        /// <param name="dataInicio">data de Inicio para a qual se pretende gerar as facturas</param>
        /// <param name="dataFim">data de Fim para a qual se pretende gerar as facturas</param>
        /// <returns>Enumerrio que indica o sucesso ou insucesso da operao.</returns>
        TelecomunicacoesEnum.EnumGeral GerarFacturas(string login, string password, DateTime dataInicio, DateTime dataFim);
        /// <summary>
        /// Este mtodo permite gerar facturas para um determinado nmero de telefone existente no sistema.
        /// </summary>
        /// <param name="login">Login do utilizador para efeitos de autenticao</param>
        /// <param name="password">Password do cliente para efeitos de autenticao</param>
        /// <param name="dataInicio">Data de incio para a qual se pretende gerar facturas</param>
        /// <param name="dataFim">Data de Fim para a qual se pretend gerar as facturas</param>
        /// <param name="numeroTelefone">Nmero de telefone para o qual vo ser geradas as facturas.</param>
        /// <returns>Retora um enumerrio que indica se a operao foi bem sucedida ou no.</returns>
        TelecomunicacoesEnum.EnumGeral GerarFacturas(string login, string password, DateTime dataInicio, DateTime dataFim, string numeroTelefone);
        /// <summary>
        /// Mtodo para desactivar desta interface, colocado como pbllico apenas para efeitos de teste
        /// </summary>
        /// <param name="numeroTelefone"></param>
        /// <returns></returns>
        System.Data.DataSet ObterDetalhesCartaoActivo(string numeroTelefone);
    }
}
