using System;
using System.Collections.Generic;
using System.Text;
using ModuloComum;

namespace Telecomunicacoes
{
    public interface ICliente
    {
        /// <summary>
        /// Mtodo que permite criar um cliente novo. Este mtodo faz um conjunto de validaes e devolve um enumerrio
        /// correspondente.  obrigatria a introduo de um dos documentos (bi/nmero de contribuinte). Caso no tenha 
        /// um dos documentos dever passar o valor 0 nesse campo.
        /// </summary>
        /// <param name="login">Login para efeitos de autenticao e verificao de permisses para usar mtodo.</param>
        /// <param name="password">Password para efeitos de autenticao e verificao de permisses para usar o mtodo.</param>
        /// <param name="nome">String que contm o nome do novo cliente a criar</param>
        /// <param name="morada">Morada do cliente a criar.</param>
        /// <param name="numeroContribuinte">Numero de contribuinte do cliente a criar. Este nmero ser usado para efeitos de validao no sistema.</param>
        /// <param name="numeroTelemovelAssociado">Nmero de telefone ao qual est a ser associado o cliente.</param>
        /// <param name="numeroCartaoAssociado">Nmero do carto ao qual se pretende associar o cliente.
        /// </param>
        /// <param name="numeroBI">Nmero de Bilhete de Identidade do cliente;</param>
        /// <returns>Enumerrio que indica o estado da operao.</returns>
        TelecomunicacoesEnum.EnumGeral CriarCliente(string login, string password, string nome, string morada, string numeroContribuinte, string numeroBI, string numeroTelemovelAssociado,string numeroCartaoAssociado);
        /// <summary>
        /// Mtodo que permite criar um novo cliente e associa-lo a um ou mais cartes ou nmeros de telefone. Os parmetros numeroTelefoneAssociado e numeroCartaoAssociado, so opcionais, 
        /// sendo obrigatrio o preenchimento de um deles. Os parmetros numeroContribuinte e numeroBI so parmetros que serviro 
        /// para verficar a existncia ou no do cliente no sistema. Se o cliente j existir a criao do cliente no ser realizada com sucesso
        /// e ser retornada um enumerrio que identifica essa ocorrencia. Quando preenchidos ambos os vectores, o sistema tentar criar o cliente com base nos nmeros de carto ignorando os 
        /// nmeros de telemvel fornecidos. Em caso de erro numa posio do Array, toda a operao ser anulada.
        /// </summary>
        /// <param name="login">Login do utilizador para efeitos de autenticao no mtodo.</param>
        /// <param name="password">Password do utilizador para efeitos de autenticao no mtodo.</param>
        /// <param name="nome">Nome do cliente a criar.</param>
        /// <param name="morada">Morada do cliente a criar.</param>
        /// <param name="numeroContribuinte">Nmero de contribuinte do cliente a criar.</param>
        /// <param name="numeroBI">Nmero do Bilhete de Identidade do cliente.</param>
        /// <param name="numeroTelemovelAssociado">Nmero de telemvel associado. Este nmero  opcional, podendo der indicado alternativamente o n do carto.</param>
        /// <param name="numeroCartaoAssociado">Nmero do carto associado.</param>
        /// <returns>Enumerrio que indica se a operao foi realizada com sucesso ou caso no o tenha sido qual o problema ou a ocorrencia que provocou este problema.</returns>
        TelecomunicacoesEnum.EnumGeral CriarCliente(string login, string password, string nome, string morada, string numeroContribuinte, string numeroBI, string [] numeroTelemovelAssociado, string [] numeroCartaoAssociado);
        /// <summary>
        /// Mtodo que permite alterar o cliente bastando para isso passar o cdigo do cliente a alterar o cliente
        /// com base no DataSet que  passado como parmetro que dever obedecer  estrutura do DataSet retornado 
        /// pelo mtodo ObterCliente(string login,string password).
        /// </summary>
        /// <param name="login">Login para efeitos de autenticao no mtodo.</param>
        /// <param name="password">Password para efeitos de autenticao.</param>
        /// <param name="codigoCliente">Cdigo do cliente a alterar.</param>
        /// <param name="detalhesCliente">DataSet contendo os parmetros do cliente a serem alterados.</param>
        /// <returns>Retorna um enumerrio que indica se a operao decorreu com normalidade ou em caso de ocorrncia de 
        /// um problema retorna um enumerrio com o tipo de erro que ocorreu.</returns>
        TelecomunicacoesEnum.EnumGeral AlteraCliente(string login, string password, int codigoCliente, System.Data.DataSet detalhesCliente);
        /// <summary>
        /// Mtodo que permite obter um DataSet um conjunto de parmetros que quando devidamente preenchidos ou alterados
        /// podem caracterizar um cliente.
        /// </summary>
        /// <param name="login">Login do utilizador para efeitos de autenticao no mtodo.</param>
        /// <param name="password">Password para efeitos de autenticao no mtodo.</param>
        /// <returns>DataSet previamente definido para caracteriazr um cliente.</returns>
        System.Data.DataSet ObterCliente(string login, string password);
        /// <summary>
        /// Este mtodo permite obter os dados de um cliente de forma detalhada bastando para isso um cdigo do cliente vlido.
        /// </summary>
        /// <param name="login">Login do utilizador corrente para efeitos de autenticao no mtodo.</param>
        /// <param name="password">Password para efeitos de autenticao no mtodo.</param>
        /// <param name="codigoCliente">Cdigo do cliente</param>
        /// <returns>DataSet preenchido com o detalhe de um dado cliente.</returns>
        System.Data.DataSet ObterCliente(string login,string password, int codigoCliente);
        /// <summary>
        /// O mtodo gerar facturas permite gerar uma ou mais facturas para o cliente passado como parmetro, quando passada a data de Inicio e de Fim. 
        /// </summary>
        /// <param name="login">Login do utilizador para efeitos de autenticao</param>
        /// <param name="password">Password do utilizador para efeitos de autenticao</param>
        /// <param name="dataInicio">Data de Inicio para a considerar para emisso de facturas</param>
        /// <param name="dataFim">Data de fim a considerar para emisso de facturas</param>
        /// <returns>Enumerrio que indica o sucesso ou insucesso da operao. Em caso de insucesso o erro retornado deve indicar a razo do Insucesso. </returns>
        System.Data.DataSet GerarFacturas(string login, string password,int codigoCliente,DateTime dataInicio, DateTime dataFim);
        
    }
}
